Method: Sycl::Array#render_unsorted!

Defined in:
lib/sycl.rb

#render_unsorted!Object

Do not sort this array when it is rendered as YAML. Usually we want elements sorted so that diffs are human-readable, however, there are certain cases where array ordering is significant (for example, a sorted list of queues).



291
292
293
# File 'lib/sycl.rb', line 291

def render_unsorted!
  @render_sorted = false
end